@@ -10,7 +10,7 @@
 	SSO_CMN_DEQ_BURST(cn10k_sso_hws_deq_burst_##name,                      \
 			  cn10k_sso_hws_deq_##name, flags)                     \
 	SSO_CMN_DEQ_BURST(cn10k_sso_hws_reas_deq_burst_##name,                 \
-			  cn10k_sso_hws_reas_deq_##name, flags | NIX_RX_REAS_F)
+			  cn10k_sso_hws_reas_deq_##name, flags | NIX_RX_REAS_F_)
 
-NIX_RX_FASTPATH_MODES_80_95
+NIX_RX_FASTPATH_MODES_32_47
 #undef R
